NAME
pdf-lbr-edit-bib - Edit BibTeX bibliographic metadata in PDF files.
SYNOPSIS
pdf-lbr-edit-bib --version pdf-lbr-edit-bib --help|-h
pdf-lbr-edit-bib links|link-directories ...
... links|link-directories ... | pdf-lbr-edit-bib ...
DESCRIPTION
pdf-lbr-edit-bib reads BibTeX bibliographic metadata embedded in PDF files given by links and/or within link-directories in the PDF links directory. If links|link-directories are not given on the command line, they are read from standard input, one per line.
The BibTeX metadata is written to a temporary file, which is then opened in an editing program, given either by the $VISUAL or $EDITOR environment variables, or else the program editor. The macros section of the configuration file is parsed for custom BibTeX macros to define.
Any modifications are then written back to the PDF files given by the file field in each BibTeX entry, and the PDF library links rebuilt as needed.
PART OF
App::PDFLibrarian
COPYRIGHT AND LICENSE
Copyright (C) 2016--2026 Karl Wette. Licensed under the GNU General Public License, version 3 or later.